@@ -66,7 +66,7 @@ int main(int argc, char *argv[])
                          QStringLiteral("Set alarms and timers, use a stopwatch, and manage world clocks"),
                          KAboutLicense::GPL,
                          i18n("© 2020-2022 KDE Community"));
-    aboutData.setBugAddress("https://invent.kde.org/plasma-mobile/kclock/-/issues");
+    aboutData.setBugAddress("https://bugs.kde.org/describecomponents.cgi?product=KClock");
     aboutData.addAuthor(i18n("Devin Lin"), QString(), QStringLiteral("devin@kde.org"));
     aboutData.addAuthor(i18n("Han Young"), QString(), QStringLiteral("hanyoung@protonmail.com"));
     KAboutData::setApplicationData(aboutData);
