@@ -4,18 +4,19 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef KCLOCKD_ALARMWAITWORKER_H
-#define KCLOCKD_ALARMWAITWORKER_H
+#pragma once
 
 #include <QObject>
 
 class AlarmWaitWorker : public QObject
 {
     Q_OBJECT
+
 public:
     explicit AlarmWaitWorker(quint64 timestamp = 0);
 
     void setNewTime(quint64 timestamp); // set new wait time, if is currently waiting
+
 Q_SIGNALS:
     void finished();
     void error();
@@ -30,5 +31,3 @@ private:
     quint64 m_waitEndTime;
     bool m_isFinished = true;
 };
-
-#endif // KCLOCKD_ALARMWAITWORKER_H
